@@ -6,7 +6,7 @@ from __future__ import division, absolute_import
 
 import numpy as np
 
-from ._cvodes import adaptive, predefined, requires_jac, steppers, fpes, iterative_linsols
+from ._cvodes import adaptive, predefined, requires_jac, steppers, fpes, iterative_linsols, sundials_version
 from ._util import _check_callable, _check_indexing, _check_jac_type
 from ._release import __version__
 from ._config import env as config
@@ -71,7 +71,7 @@ def integrate_adaptive(rhs, jac, y0, x0, xend, atol, rtol, dx0=.0,
         perform signature sanity checks on ``rhs`` and ``jac``
     check_indexing : bool
         Perform item setting sanity checks on ``rhs`` and ``jac``.
-    \*\*kwargs:
+    \\*\\*kwargs:
         'lband' : int
             Number of lower bands.
             Indexing: ``banded[row_i - col_i + uband, col_i]``.
@@ -118,6 +118,13 @@ def integrate_adaptive(rhs, jac, y0, x0, xend, atol, rtol, dx0=.0,
             For use with linear solvers 'gmres', 'gmres_classic', 'bicgstab', 'tfqmr'.
         'ew_ele' : bool
             Whether to return error_weights, estimated_local_errors in info dict.
+        'constraints': array
+            Per component constraints 0.0: no constraint, 1.0: >=0, -1.0: <=0, 2.0: >0.0, -2.0: <0.0.
+        'max_steps_between_jac': int
+             Maximum  number  of  timesteps to wait before recomputation of the Jacobian or
+             recommendation to update the preconditioner.
+        'stab_lim_det': bool
+             Use CVodes built in stability limit detection. (default: False)
 
     Returns
     -------
@@ -194,7 +201,7 @@ def integrate_predefined(rhs, jac, y0, xout, atol, rtol, jac_type="dense",
         Perform signature sanity checks on ``rhs`` and ``jac``.
     check_indexing : bool (default: False)
         Perform item setting sanity checks on ``rhs`` and ``jac``.
-    \*\*kwargs:
+    \\*\\*kwargs:
         'lband' : int
             Number of lower bands.
             Indexing: ``banded[row_i - col_i + uband, col_i]``.
@@ -241,6 +248,13 @@ def integrate_predefined(rhs, jac, y0, xout, atol, rtol, jac_type="dense",
             For use with linear solvers 'gmres', 'gmres_classic', 'bicgstab', 'tfqmr'.
         'ew_ele' : bool
             Whether to return error_weights, estimated_local_errors in info dict.
+        'constraints': array
+            Per component constraints 0.0: no constraint, 1.0: >=0, -1.0: <=0, 2.0: >0.0, -2.0: <0.0.
+        'max_steps_between_jac': int
+             Maximum  number  of  timesteps to wait before recomputation of the Jacobian or
+             recommendation to update the preconditioner.
+        'stab_lim_det': bool
+             Use CVodes built in stability limit detection. (default: False)
 
     Returns
     -------
